@@ -43,10 +43,10 @@ else:
 
 __all__ = (
     "AWSSessionCredentialsTypeDef",
-    "AcknowledgeJobInputTypeDef",
-    "AcknowledgeJobOutputResponseTypeDef",
-    "AcknowledgeThirdPartyJobInputTypeDef",
-    "AcknowledgeThirdPartyJobOutputResponseTypeDef",
+    "AcknowledgeJobInputRequestTypeDef",
+    "AcknowledgeJobOutputTypeDef",
+    "AcknowledgeThirdPartyJobInputRequestTypeDef",
+    "AcknowledgeThirdPartyJobOutputTypeDef",
     "ActionConfigurationPropertyTypeDef",
     "ActionConfigurationTypeDef",
     "ActionContextTypeDef",
@@ -77,54 +77,54 @@ __all__ = (
     "ArtifactStoreTypeDef",
     "ArtifactTypeDef",
     "BlockerDeclarationTypeDef",
-    "CreateCustomActionTypeInputTypeDef",
-    "CreateCustomActionTypeOutputResponseTypeDef",
-    "CreatePipelineInputTypeDef",
-    "CreatePipelineOutputResponseTypeDef",
+    "CreateCustomActionTypeInputRequestTypeDef",
+    "CreateCustomActionTypeOutputTypeDef",
+    "CreatePipelineInputRequestTypeDef",
+    "CreatePipelineOutputTypeDef",
     "CurrentRevisionTypeDef",
-    "DeleteCustomActionTypeInputTypeDef",
-    "DeletePipelineInputTypeDef",
-    "DeleteWebhookInputTypeDef",
-    "DeregisterWebhookWithThirdPartyInputTypeDef",
-    "DisableStageTransitionInputTypeDef",
-    "EnableStageTransitionInputTypeDef",
+    "DeleteCustomActionTypeInputRequestTypeDef",
+    "DeletePipelineInputRequestTypeDef",
+    "DeleteWebhookInputRequestTypeDef",
+    "DeregisterWebhookWithThirdPartyInputRequestTypeDef",
+    "DisableStageTransitionInputRequestTypeDef",
+    "EnableStageTransitionInputRequestTypeDef",
     "EncryptionKeyTypeDef",
     "ErrorDetailsTypeDef",
     "ExecutionDetailsTypeDef",
     "ExecutionTriggerTypeDef",
     "ExecutorConfigurationTypeDef",
     "FailureDetailsTypeDef",
-    "GetActionTypeInputTypeDef",
-    "GetActionTypeOutputResponseTypeDef",
-    "GetJobDetailsInputTypeDef",
-    "GetJobDetailsOutputResponseTypeDef",
-    "GetPipelineExecutionInputTypeDef",
-    "GetPipelineExecutionOutputResponseTypeDef",
-    "GetPipelineInputTypeDef",
-    "GetPipelineOutputResponseTypeDef",
-    "GetPipelineStateInputTypeDef",
-    "GetPipelineStateOutputResponseTypeDef",
-    "GetThirdPartyJobDetailsInputTypeDef",
-    "GetThirdPartyJobDetailsOutputResponseTypeDef",
+    "GetActionTypeInputRequestTypeDef",
+    "GetActionTypeOutputTypeDef",
+    "GetJobDetailsInputRequestTypeDef",
+    "GetJobDetailsOutputTypeDef",
+    "GetPipelineExecutionInputRequestTypeDef",
+    "GetPipelineExecutionOutputTypeDef",
+    "GetPipelineInputRequestTypeDef",
+    "GetPipelineOutputTypeDef",
+    "GetPipelineStateInputRequestTypeDef",
+    "GetPipelineStateOutputTypeDef",
+    "GetThirdPartyJobDetailsInputRequestTypeDef",
+    "GetThirdPartyJobDetailsOutputTypeDef",
     "InputArtifactTypeDef",
     "JobDataTypeDef",
     "JobDetailsTypeDef",
     "JobTypeDef",
     "JobWorkerExecutorConfigurationTypeDef",
     "LambdaExecutorConfigurationTypeDef",
-    "ListActionExecutionsInputTypeDef",
-    "ListActionExecutionsOutputResponseTypeDef",
-    "ListActionTypesInputTypeDef",
-    "ListActionTypesOutputResponseTypeDef",
-    "ListPipelineExecutionsInputTypeDef",
-    "ListPipelineExecutionsOutputResponseTypeDef",
-    "ListPipelinesInputTypeDef",
-    "ListPipelinesOutputResponseTypeDef",
-    "ListTagsForResourceInputTypeDef",
-    "ListTagsForResourceOutputResponseTypeDef",
+    "ListActionExecutionsInputRequestTypeDef",
+    "ListActionExecutionsOutputTypeDef",
+    "ListActionTypesInputRequestTypeDef",
+    "ListActionTypesOutputTypeDef",
+    "ListPipelineExecutionsInputRequestTypeDef",
+    "ListPipelineExecutionsOutputTypeDef",
+    "ListPipelinesInputRequestTypeDef",
+    "ListPipelinesOutputTypeDef",
+    "ListTagsForResourceInputRequestTypeDef",
+    "ListTagsForResourceOutputTypeDef",
     "ListWebhookItemTypeDef",
-    "ListWebhooksInputTypeDef",
-    "ListWebhooksOutputResponseTypeDef",
+    "ListWebhooksInputRequestTypeDef",
+    "ListWebhooksOutputTypeDef",
     "OutputArtifactTypeDef",
     "PaginatorConfigTypeDef",
     "PipelineContextTypeDef",
@@ -133,24 +133,24 @@ __all__ = (
     "PipelineExecutionTypeDef",
     "PipelineMetadataTypeDef",
     "PipelineSummaryTypeDef",
-    "PollForJobsInputTypeDef",
-    "PollForJobsOutputResponseTypeDef",
-    "PollForThirdPartyJobsInputTypeDef",
-    "PollForThirdPartyJobsOutputResponseTypeDef",
-    "PutActionRevisionInputTypeDef",
-    "PutActionRevisionOutputResponseTypeDef",
-    "PutApprovalResultInputTypeDef",
-    "PutApprovalResultOutputResponseTypeDef",
-    "PutJobFailureResultInputTypeDef",
-    "PutJobSuccessResultInputTypeDef",
-    "PutThirdPartyJobFailureResultInputTypeDef",
-    "PutThirdPartyJobSuccessResultInputTypeDef",
-    "PutWebhookInputTypeDef",
-    "PutWebhookOutputResponseTypeDef",
-    "RegisterWebhookWithThirdPartyInputTypeDef",
+    "PollForJobsInputRequestTypeDef",
+    "PollForJobsOutputTypeDef",
+    "PollForThirdPartyJobsInputRequestTypeDef",
+    "PollForThirdPartyJobsOutputTypeDef",
+    "PutActionRevisionInputRequestTypeDef",
+    "PutActionRevisionOutputTypeDef",
+    "PutApprovalResultInputRequestTypeDef",
+    "PutApprovalResultOutputTypeDef",
+    "PutJobFailureResultInputRequestTypeDef",
+    "PutJobSuccessResultInputRequestTypeDef",
+    "PutThirdPartyJobFailureResultInputRequestTypeDef",
+    "PutThirdPartyJobSuccessResultInputRequestTypeDef",
+    "PutWebhookInputRequestTypeDef",
+    "PutWebhookOutputTypeDef",
+    "RegisterWebhookWithThirdPartyInputRequestTypeDef",
     "ResponseMetadataTypeDef",
-    "RetryStageExecutionInputTypeDef",
-    "RetryStageExecutionOutputResponseTypeDef",
+    "RetryStageExecutionInputRequestTypeDef",
+    "RetryStageExecutionOutputTypeDef",
     "S3ArtifactLocationTypeDef",
     "S3LocationTypeDef",
     "SourceRevisionTypeDef",
@@ -158,21 +158,21 @@ __all__ = (
     "StageDeclarationTypeDef",
     "StageExecutionTypeDef",
     "StageStateTypeDef",
-    "StartPipelineExecutionInputTypeDef",
-    "StartPipelineExecutionOutputResponseTypeDef",
+    "StartPipelineExecutionInputRequestTypeDef",
+    "StartPipelineExecutionOutputTypeDef",
     "StopExecutionTriggerTypeDef",
-    "StopPipelineExecutionInputTypeDef",
-    "StopPipelineExecutionOutputResponseTypeDef",
-    "TagResourceInputTypeDef",
+    "StopPipelineExecutionInputRequestTypeDef",
+    "StopPipelineExecutionOutputTypeDef",
+    "TagResourceInputRequestTypeDef",
     "TagTypeDef",
     "ThirdPartyJobDataTypeDef",
     "ThirdPartyJobDetailsTypeDef",
     "ThirdPartyJobTypeDef",
     "TransitionStateTypeDef",
-    "UntagResourceInputTypeDef",
-    "UpdateActionTypeInputTypeDef",
-    "UpdatePipelineInputTypeDef",
-    "UpdatePipelineOutputResponseTypeDef",
+    "UntagResourceInputRequestTypeDef",
+    "UpdateActionTypeInputRequestTypeDef",
+    "UpdatePipelineInputRequestTypeDef",
+    "UpdatePipelineOutputTypeDef",
     "WebhookAuthConfigurationTypeDef",
     "WebhookDefinitionTypeDef",
     "WebhookFilterRuleTypeDef",
@@ -187,24 +187,24 @@ AWSSessionCredentialsTypeDef = TypedDict(
     },
 )
 
-AcknowledgeJobInputTypeDef = TypedDict(
-    "AcknowledgeJobInputTypeDef",
+AcknowledgeJobInputRequestTypeDef = TypedDict(
+    "AcknowledgeJobInputRequestTypeDef",
     {
         "jobId": str,
         "nonce": str,
     },
 )
 
-AcknowledgeJobOutputResponseTypeDef = TypedDict(
-    "AcknowledgeJobOutputResponseTypeDef",
+AcknowledgeJobOutputTypeDef = TypedDict(
+    "AcknowledgeJobOutputTypeDef",
     {
         "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-AcknowledgeThirdPartyJobInputTypeDef = TypedDict(
-    "AcknowledgeThirdPartyJobInputTypeDef",
+AcknowledgeThirdPartyJobInputRequestTypeDef = TypedDict(
+    "AcknowledgeThirdPartyJobInputRequestTypeDef",
     {
         "jobId": str,
         "nonce": str,
@@ -212,8 +212,8 @@ AcknowledgeThirdPartyJobInputTypeDef = TypedDict(
     },
 )
 
-AcknowledgeThirdPartyJobOutputResponseTypeDef = TypedDict(
-    "AcknowledgeThirdPartyJobOutputResponseTypeDef",
+AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
+    "AcknowledgeThirdPartyJobOutputTypeDef",
     {
         "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -627,8 +627,8 @@ BlockerDeclarationTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateCustomActionTypeInputTypeDef = TypedDict(
-    "_RequiredCreateCustomActionTypeInputTypeDef",
+_RequiredCreateCustomActionTypeInputRequestTypeDef = TypedDict(
+    "_RequiredCreateCustomActionTypeInputRequestTypeDef",
     {
         "category": ActionCategoryType,
         "provider": str,
@@ -637,8 +637,8 @@ _RequiredCreateCustomActionTypeInputTypeDef = TypedDict(
         "outputArtifactDetails": "ArtifactDetailsTypeDef",
     },
 )
-_OptionalCreateCustomActionTypeInputTypeDef = TypedDict(
-    "_OptionalCreateCustomActionTypeInputTypeDef",
+_OptionalCreateCustomActionTypeInputRequestTypeDef = TypedDict(
+    "_OptionalCreateCustomActionTypeInputRequestTypeDef",
     {
         "settings": "ActionTypeSettingsTypeDef",
         "configurationProperties": List["ActionConfigurationPropertyTypeDef"],
@@ -648,14 +648,15 @@ _OptionalCreateCustomActionTypeInputTypeDef = TypedDict(
 )
 
 
-class CreateCustomActionTypeInputTypeDef(
-    _RequiredCreateCustomActionTypeInputTypeDef, _OptionalCreateCustomActionTypeInputTypeDef
+class CreateCustomActionTypeInputRequestTypeDef(
+    _RequiredCreateCustomActionTypeInputRequestTypeDef,
+    _OptionalCreateCustomActionTypeInputRequestTypeDef,
 ):
     pass
 
 
-CreateCustomActionTypeOutputResponseTypeDef = TypedDict(
-    "CreateCustomActionTypeOutputResponseTypeDef",
+CreateCustomActionTypeOutputTypeDef = TypedDict(
+    "CreateCustomActionTypeOutputTypeDef",
     {
         "actionType": "ActionTypeTypeDef",
         "tags": List["TagTypeDef"],
@@ -663,14 +664,14 @@ CreateCustomActionTypeOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreatePipelineInputTypeDef = TypedDict(
-    "_RequiredCreatePipelineInputTypeDef",
+_RequiredCreatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineInputRequestTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
     },
 )
-_OptionalCreatePipelineInputTypeDef = TypedDict(
-    "_OptionalCreatePipelineInputTypeDef",
+_OptionalCreatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineInputRequestTypeDef",
     {
         "tags": List["TagTypeDef"],
     },
@@ -678,14 +679,14 @@ _OptionalCreatePipelineInputTypeDef = TypedDict(
 )
 
 
-class CreatePipelineInputTypeDef(
-    _RequiredCreatePipelineInputTypeDef, _OptionalCreatePipelineInputTypeDef
+class CreatePipelineInputRequestTypeDef(
+    _RequiredCreatePipelineInputRequestTypeDef, _OptionalCreatePipelineInputRequestTypeDef
 ):
     pass
 
 
-CreatePipelineOutputResponseTypeDef = TypedDict(
-    "CreatePipelineOutputResponseTypeDef",
+CreatePipelineOutputTypeDef = TypedDict(
+    "CreatePipelineOutputTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "tags": List["TagTypeDef"],
@@ -714,8 +715,8 @@ class CurrentRevisionTypeDef(_RequiredCurrentRevisionTypeDef, _OptionalCurrentRe
     pass
 
 
-DeleteCustomActionTypeInputTypeDef = TypedDict(
-    "DeleteCustomActionTypeInputTypeDef",
+DeleteCustomActionTypeInputRequestTypeDef = TypedDict(
+    "DeleteCustomActionTypeInputRequestTypeDef",
     {
         "category": ActionCategoryType,
         "provider": str,
@@ -723,30 +724,30 @@ DeleteCustomActionTypeInputTypeDef = TypedDict(
     },
 )
 
-DeletePipelineInputTypeDef = TypedDict(
-    "DeletePipelineInputTypeDef",
+DeletePipelineInputRequestTypeDef = TypedDict(
+    "DeletePipelineInputRequestTypeDef",
     {
         "name": str,
     },
 )
 
-DeleteWebhookInputTypeDef = TypedDict(
-    "DeleteWebhookInputTypeDef",
+DeleteWebhookInputRequestTypeDef = TypedDict(
+    "DeleteWebhookInputRequestTypeDef",
     {
         "name": str,
     },
 )
 
-DeregisterWebhookWithThirdPartyInputTypeDef = TypedDict(
-    "DeregisterWebhookWithThirdPartyInputTypeDef",
+DeregisterWebhookWithThirdPartyInputRequestTypeDef = TypedDict(
+    "DeregisterWebhookWithThirdPartyInputRequestTypeDef",
     {
         "webhookName": str,
     },
     total=False,
 )
 
-DisableStageTransitionInputTypeDef = TypedDict(
-    "DisableStageTransitionInputTypeDef",
+DisableStageTransitionInputRequestTypeDef = TypedDict(
+    "DisableStageTransitionInputRequestTypeDef",
     {
         "pipelineName": str,
         "stageName": str,
@@ -755,8 +756,8 @@ DisableStageTransitionInputTypeDef = TypedDict(
     },
 )
 
-EnableStageTransitionInputTypeDef = TypedDict(
-    "EnableStageTransitionInputTypeDef",
+EnableStageTransitionInputRequestTypeDef = TypedDict(
+    "EnableStageTransitionInputRequestTypeDef",
     {
         "pipelineName": str,
         "stageName": str,
@@ -829,8 +830,8 @@ class FailureDetailsTypeDef(_RequiredFailureDetailsTypeDef, _OptionalFailureDeta
     pass
 
 
-GetActionTypeInputTypeDef = TypedDict(
-    "GetActionTypeInputTypeDef",
+GetActionTypeInputRequestTypeDef = TypedDict(
+    "GetActionTypeInputRequestTypeDef",
     {
         "category": ActionCategoryType,
         "owner": str,
@@ -839,53 +840,53 @@ GetActionTypeInputTypeDef = TypedDict(
     },
 )
 
-GetActionTypeOutputResponseTypeDef = TypedDict(
-    "GetActionTypeOutputResponseTypeDef",
+GetActionTypeOutputTypeDef = TypedDict(
+    "GetActionTypeOutputTypeDef",
     {
         "actionType": "ActionTypeDeclarationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetJobDetailsInputTypeDef = TypedDict(
-    "GetJobDetailsInputTypeDef",
+GetJobDetailsInputRequestTypeDef = TypedDict(
+    "GetJobDetailsInputRequestTypeDef",
     {
         "jobId": str,
     },
 )
 
-GetJobDetailsOutputResponseTypeDef = TypedDict(
-    "GetJobDetailsOutputResponseTypeDef",
+GetJobDetailsOutputTypeDef = TypedDict(
+    "GetJobDetailsOutputTypeDef",
     {
         "jobDetails": "JobDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetPipelineExecutionInputTypeDef = TypedDict(
-    "GetPipelineExecutionInputTypeDef",
+GetPipelineExecutionInputRequestTypeDef = TypedDict(
+    "GetPipelineExecutionInputRequestTypeDef",
     {
         "pipelineName": str,
         "pipelineExecutionId": str,
     },
 )
 
-GetPipelineExecutionOutputResponseTypeDef = TypedDict(
-    "GetPipelineExecutionOutputResponseTypeDef",
+GetPipelineExecutionOutputTypeDef = TypedDict(
+    "GetPipelineExecutionOutputTypeDef",
     {
         "pipelineExecution": "PipelineExecutionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetPipelineInputTypeDef = TypedDict(
-    "_RequiredGetPipelineInputTypeDef",
+_RequiredGetPipelineInputRequestTypeDef = TypedDict(
+    "_RequiredGetPipelineInputRequestTypeDef",
     {
         "name": str,
     },
 )
-_OptionalGetPipelineInputTypeDef = TypedDict(
-    "_OptionalGetPipelineInputTypeDef",
+_OptionalGetPipelineInputRequestTypeDef = TypedDict(
+    "_OptionalGetPipelineInputRequestTypeDef",
     {
         "version": int,
     },
@@ -893,12 +894,14 @@ _OptionalGetPipelineInputTypeDef = TypedDict(
 )
 
 
-class GetPipelineInputTypeDef(_RequiredGetPipelineInputTypeDef, _OptionalGetPipelineInputTypeDef):
+class GetPipelineInputRequestTypeDef(
+    _RequiredGetPipelineInputRequestTypeDef, _OptionalGetPipelineInputRequestTypeDef
+):
     pass
 
 
-GetPipelineOutputResponseTypeDef = TypedDict(
-    "GetPipelineOutputResponseTypeDef",
+GetPipelineOutputTypeDef = TypedDict(
+    "GetPipelineOutputTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "metadata": "PipelineMetadataTypeDef",
@@ -906,15 +909,15 @@ GetPipelineOutputResponseTypeDef = TypedDict(
     },
 )
 
-GetPipelineStateInputTypeDef = TypedDict(
-    "GetPipelineStateInputTypeDef",
+GetPipelineStateInputRequestTypeDef = TypedDict(
+    "GetPipelineStateInputRequestTypeDef",
     {
         "name": str,
     },
 )
 
-GetPipelineStateOutputResponseTypeDef = TypedDict(
-    "GetPipelineStateOutputResponseTypeDef",
+GetPipelineStateOutputTypeDef = TypedDict(
+    "GetPipelineStateOutputTypeDef",
     {
         "pipelineName": str,
         "pipelineVersion": int,
@@ -925,16 +928,16 @@ GetPipelineStateOutputResponseTypeDef = TypedDict(
     },
 )
 
-GetThirdPartyJobDetailsInputTypeDef = TypedDict(
-    "GetThirdPartyJobDetailsInputTypeDef",
+GetThirdPartyJobDetailsInputRequestTypeDef = TypedDict(
+    "GetThirdPartyJobDetailsInputRequestTypeDef",
     {
         "jobId": str,
         "clientToken": str,
     },
 )
 
-GetThirdPartyJobDetailsOutputResponseTypeDef = TypedDict(
-    "GetThirdPartyJobDetailsOutputResponseTypeDef",
+GetThirdPartyJobDetailsOutputTypeDef = TypedDict(
+    "GetThirdPartyJobDetailsOutputTypeDef",
     {
         "jobDetails": "ThirdPartyJobDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1000,14 +1003,14 @@ LambdaExecutorConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredListActionExecutionsInputTypeDef = TypedDict(
-    "_RequiredListActionExecutionsInputTypeDef",
+_RequiredListActionExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredListActionExecutionsInputRequestTypeDef",
     {
         "pipelineName": str,
     },
 )
-_OptionalListActionExecutionsInputTypeDef = TypedDict(
-    "_OptionalListActionExecutionsInputTypeDef",
+_OptionalListActionExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalListActionExecutionsInputRequestTypeDef",
     {
         "filter": "ActionExecutionFilterTypeDef",
         "maxResults": int,
@@ -1017,14 +1020,15 @@ _OptionalListActionExecutionsInputTypeDef = TypedDict(
 )
 
 
-class ListActionExecutionsInputTypeDef(
-    _RequiredListActionExecutionsInputTypeDef, _OptionalListActionExecutionsInputTypeDef
+class ListActionExecutionsInputRequestTypeDef(
+    _RequiredListActionExecutionsInputRequestTypeDef,
+    _OptionalListActionExecutionsInputRequestTypeDef,
 ):
     pass
 
 
-ListActionExecutionsOutputResponseTypeDef = TypedDict(
-    "ListActionExecutionsOutputResponseTypeDef",
+ListActionExecutionsOutputTypeDef = TypedDict(
+    "ListActionExecutionsOutputTypeDef",
     {
         "actionExecutionDetails": List["ActionExecutionDetailTypeDef"],
         "nextToken": str,
@@ -1032,8 +1036,8 @@ ListActionExecutionsOutputResponseTypeDef = TypedDict(
     },
 )
 
-ListActionTypesInputTypeDef = TypedDict(
-    "ListActionTypesInputTypeDef",
+ListActionTypesInputRequestTypeDef = TypedDict(
+    "ListActionTypesInputRequestTypeDef",
     {
         "actionOwnerFilter": ActionOwnerType,
         "nextToken": str,
@@ -1042,8 +1046,8 @@ ListActionTypesInputTypeDef = TypedDict(
     total=False,
 )
 
-ListActionTypesOutputResponseTypeDef = TypedDict(
-    "ListActionTypesOutputResponseTypeDef",
+ListActionTypesOutputTypeDef = TypedDict(
+    "ListActionTypesOutputTypeDef",
     {
         "actionTypes": List["ActionTypeTypeDef"],
         "nextToken": str,
@@ -1051,14 +1055,14 @@ ListActionTypesOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListPipelineExecutionsInputTypeDef = TypedDict(
-    "_RequiredListPipelineExecutionsInputTypeDef",
+_RequiredListPipelineExecutionsInputRequestTypeDef = TypedDict(
+    "_RequiredListPipelineExecutionsInputRequestTypeDef",
     {
         "pipelineName": str,
     },
 )
-_OptionalListPipelineExecutionsInputTypeDef = TypedDict(
-    "_OptionalListPipelineExecutionsInputTypeDef",
+_OptionalListPipelineExecutionsInputRequestTypeDef = TypedDict(
+    "_OptionalListPipelineExecutionsInputRequestTypeDef",
     {
         "maxResults": int,
         "nextToken": str,
@@ -1067,14 +1071,15 @@ _OptionalListPipelineExecutionsInputTypeDef = TypedDict(
 )
 
 
-class ListPipelineExecutionsInputTypeDef(
-    _RequiredListPipelineExecutionsInputTypeDef, _OptionalListPipelineExecutionsInputTypeDef
+class ListPipelineExecutionsInputRequestTypeDef(
+    _RequiredListPipelineExecutionsInputRequestTypeDef,
+    _OptionalListPipelineExecutionsInputRequestTypeDef,
 ):
     pass
 
 
-ListPipelineExecutionsOutputResponseTypeDef = TypedDict(
-    "ListPipelineExecutionsOutputResponseTypeDef",
+ListPipelineExecutionsOutputTypeDef = TypedDict(
+    "ListPipelineExecutionsOutputTypeDef",
     {
         "pipelineExecutionSummaries": List["PipelineExecutionSummaryTypeDef"],
         "nextToken": str,
@@ -1082,8 +1087,8 @@ ListPipelineExecutionsOutputResponseTypeDef = TypedDict(
     },
 )
 
-ListPipelinesInputTypeDef = TypedDict(
-    "ListPipelinesInputTypeDef",
+ListPipelinesInputRequestTypeDef = TypedDict(
+    "ListPipelinesInputRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -1091,8 +1096,8 @@ ListPipelinesInputTypeDef = TypedDict(
     total=False,
 )
 
-ListPipelinesOutputResponseTypeDef = TypedDict(
-    "ListPipelinesOutputResponseTypeDef",
+ListPipelinesOutputTypeDef = TypedDict(
+    "ListPipelinesOutputTypeDef",
     {
         "pipelines": List["PipelineSummaryTypeDef"],
         "nextToken": str,
@@ -1100,14 +1105,14 @@ ListPipelinesOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTagsForResourceInputTypeDef = TypedDict(
-    "_RequiredListTagsForResourceInputTypeDef",
+_RequiredListTagsForResourceInputRequestTypeDef = TypedDict(
+    "_RequiredListTagsForResourceInputRequestTypeDef",
     {
         "resourceArn": str,
     },
 )
-_OptionalListTagsForResourceInputTypeDef = TypedDict(
-    "_OptionalListTagsForResourceInputTypeDef",
+_OptionalListTagsForResourceInputRequestTypeDef = TypedDict(
+    "_OptionalListTagsForResourceInputRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -1116,14 +1121,14 @@ _OptionalListTagsForResourceInputTypeDef = TypedDict(
 )
 
 
-class ListTagsForResourceInputTypeDef(
-    _RequiredListTagsForResourceInputTypeDef, _OptionalListTagsForResourceInputTypeDef
+class ListTagsForResourceInputRequestTypeDef(
+    _RequiredListTagsForResourceInputRequestTypeDef, _OptionalListTagsForResourceInputRequestTypeDef
 ):
     pass
 
 
-ListTagsForResourceOutputResponseTypeDef = TypedDict(
-    "ListTagsForResourceOutputResponseTypeDef",
+ListTagsForResourceOutputTypeDef = TypedDict(
+    "ListTagsForResourceOutputTypeDef",
     {
         "tags": List["TagTypeDef"],
         "nextToken": str,
@@ -1155,8 +1160,8 @@ class ListWebhookItemTypeDef(_RequiredListWebhookItemTypeDef, _OptionalListWebho
     pass
 
 
-ListWebhooksInputTypeDef = TypedDict(
-    "ListWebhooksInputTypeDef",
+ListWebhooksInputRequestTypeDef = TypedDict(
+    "ListWebhooksInputRequestTypeDef",
     {
         "NextToken": str,
         "MaxResults": int,
@@ -1164,8 +1169,8 @@ ListWebhooksInputTypeDef = TypedDict(
     total=False,
 )
 
-ListWebhooksOutputResponseTypeDef = TypedDict(
-    "ListWebhooksOutputResponseTypeDef",
+ListWebhooksOutputTypeDef = TypedDict(
+    "ListWebhooksOutputTypeDef",
     {
         "webhooks": List["ListWebhookItemTypeDef"],
         "NextToken": str,
@@ -1275,14 +1280,14 @@ PipelineSummaryTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPollForJobsInputTypeDef = TypedDict(
-    "_RequiredPollForJobsInputTypeDef",
+_RequiredPollForJobsInputRequestTypeDef = TypedDict(
+    "_RequiredPollForJobsInputRequestTypeDef",
     {
         "actionTypeId": "ActionTypeIdTypeDef",
     },
 )
-_OptionalPollForJobsInputTypeDef = TypedDict(
-    "_OptionalPollForJobsInputTypeDef",
+_OptionalPollForJobsInputRequestTypeDef = TypedDict(
+    "_OptionalPollForJobsInputRequestTypeDef",
     {
         "maxBatchSize": int,
         "queryParam": Dict[str, str],
@@ -1291,26 +1296,28 @@ _OptionalPollForJobsInputTypeDef = TypedDict(
 )
 
 
-class PollForJobsInputTypeDef(_RequiredPollForJobsInputTypeDef, _OptionalPollForJobsInputTypeDef):
+class PollForJobsInputRequestTypeDef(
+    _RequiredPollForJobsInputRequestTypeDef, _OptionalPollForJobsInputRequestTypeDef
+):
     pass
 
 
-PollForJobsOutputResponseTypeDef = TypedDict(
-    "PollForJobsOutputResponseTypeDef",
+PollForJobsOutputTypeDef = TypedDict(
+    "PollForJobsOutputTypeDef",
     {
         "jobs": List["JobTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredPollForThirdPartyJobsInputTypeDef = TypedDict(
-    "_RequiredPollForThirdPartyJobsInputTypeDef",
+_RequiredPollForThirdPartyJobsInputRequestTypeDef = TypedDict(
+    "_RequiredPollForThirdPartyJobsInputRequestTypeDef",
     {
         "actionTypeId": "ActionTypeIdTypeDef",
     },
 )
-_OptionalPollForThirdPartyJobsInputTypeDef = TypedDict(
-    "_OptionalPollForThirdPartyJobsInputTypeDef",
+_OptionalPollForThirdPartyJobsInputRequestTypeDef = TypedDict(
+    "_OptionalPollForThirdPartyJobsInputRequestTypeDef",
     {
         "maxBatchSize": int,
     },
@@ -1318,22 +1325,23 @@ _OptionalPollForThirdPartyJobsInputTypeDef = TypedDict(
 )
 
 
-class PollForThirdPartyJobsInputTypeDef(
-    _RequiredPollForThirdPartyJobsInputTypeDef, _OptionalPollForThirdPartyJobsInputTypeDef
+class PollForThirdPartyJobsInputRequestTypeDef(
+    _RequiredPollForThirdPartyJobsInputRequestTypeDef,
+    _OptionalPollForThirdPartyJobsInputRequestTypeDef,
 ):
     pass
 
 
-PollForThirdPartyJobsOutputResponseTypeDef = TypedDict(
-    "PollForThirdPartyJobsOutputResponseTypeDef",
+PollForThirdPartyJobsOutputTypeDef = TypedDict(
+    "PollForThirdPartyJobsOutputTypeDef",
     {
         "jobs": List["ThirdPartyJobTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PutActionRevisionInputTypeDef = TypedDict(
-    "PutActionRevisionInputTypeDef",
+PutActionRevisionInputRequestTypeDef = TypedDict(
+    "PutActionRevisionInputRequestTypeDef",
     {
         "pipelineName": str,
         "stageName": str,
@@ -1342,8 +1350,8 @@ PutActionRevisionInputTypeDef = TypedDict(
     },
 )
 
-PutActionRevisionOutputResponseTypeDef = TypedDict(
-    "PutActionRevisionOutputResponseTypeDef",
+PutActionRevisionOutputTypeDef = TypedDict(
+    "PutActionRevisionOutputTypeDef",
     {
         "newRevision": bool,
         "pipelineExecutionId": str,
@@ -1351,8 +1359,8 @@ PutActionRevisionOutputResponseTypeDef = TypedDict(
     },
 )
 
-PutApprovalResultInputTypeDef = TypedDict(
-    "PutApprovalResultInputTypeDef",
+PutApprovalResultInputRequestTypeDef = TypedDict(
+    "PutApprovalResultInputRequestTypeDef",
     {
         "pipelineName": str,
         "stageName": str,
@@ -1362,30 +1370,30 @@ PutApprovalResultInputTypeDef = TypedDict(
     },
 )
 
-PutApprovalResultOutputResponseTypeDef = TypedDict(
-    "PutApprovalResultOutputResponseTypeDef",
+PutApprovalResultOutputTypeDef = TypedDict(
+    "PutApprovalResultOutputTypeDef",
     {
         "approvedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PutJobFailureResultInputTypeDef = TypedDict(
-    "PutJobFailureResultInputTypeDef",
+PutJobFailureResultInputRequestTypeDef = TypedDict(
+    "PutJobFailureResultInputRequestTypeDef",
     {
         "jobId": str,
         "failureDetails": "FailureDetailsTypeDef",
     },
 )
 
-_RequiredPutJobSuccessResultInputTypeDef = TypedDict(
-    "_RequiredPutJobSuccessResultInputTypeDef",
+_RequiredPutJobSuccessResultInputRequestTypeDef = TypedDict(
+    "_RequiredPutJobSuccessResultInputRequestTypeDef",
     {
         "jobId": str,
     },
 )
-_OptionalPutJobSuccessResultInputTypeDef = TypedDict(
-    "_OptionalPutJobSuccessResultInputTypeDef",
+_OptionalPutJobSuccessResultInputRequestTypeDef = TypedDict(
+    "_OptionalPutJobSuccessResultInputRequestTypeDef",
     {
         "currentRevision": "CurrentRevisionTypeDef",
         "continuationToken": str,
@@ -1396,14 +1404,14 @@ _OptionalPutJobSuccessResultInputTypeDef = TypedDict(
 )
 
 
-class PutJobSuccessResultInputTypeDef(
-    _RequiredPutJobSuccessResultInputTypeDef, _OptionalPutJobSuccessResultInputTypeDef
+class PutJobSuccessResultInputRequestTypeDef(
+    _RequiredPutJobSuccessResultInputRequestTypeDef, _OptionalPutJobSuccessResultInputRequestTypeDef
 ):
     pass
 
 
-PutThirdPartyJobFailureResultInputTypeDef = TypedDict(
-    "PutThirdPartyJobFailureResultInputTypeDef",
+PutThirdPartyJobFailureResultInputRequestTypeDef = TypedDict(
+    "PutThirdPartyJobFailureResultInputRequestTypeDef",
     {
         "jobId": str,
         "clientToken": str,
@@ -1411,15 +1419,15 @@ PutThirdPartyJobFailureResultInputTypeDef = TypedDict(
     },
 )
 
-_RequiredPutThirdPartyJobSuccessResultInputTypeDef = TypedDict(
-    "_RequiredPutThirdPartyJobSuccessResultInputTypeDef",
+_RequiredPutThirdPartyJobSuccessResultInputRequestTypeDef = TypedDict(
+    "_RequiredPutThirdPartyJobSuccessResultInputRequestTypeDef",
     {
         "jobId": str,
         "clientToken": str,
     },
 )
-_OptionalPutThirdPartyJobSuccessResultInputTypeDef = TypedDict(
-    "_OptionalPutThirdPartyJobSuccessResultInputTypeDef",
+_OptionalPutThirdPartyJobSuccessResultInputRequestTypeDef = TypedDict(
+    "_OptionalPutThirdPartyJobSuccessResultInputRequestTypeDef",
     {
         "currentRevision": "CurrentRevisionTypeDef",
         "continuationToken": str,
@@ -1429,21 +1437,21 @@ _OptionalPutThirdPartyJobSuccessResultInputTypeDef = TypedDict(
 )
 
 
-class PutThirdPartyJobSuccessResultInputTypeDef(
-    _RequiredPutThirdPartyJobSuccessResultInputTypeDef,
-    _OptionalPutThirdPartyJobSuccessResultInputTypeDef,
+class PutThirdPartyJobSuccessResultInputRequestTypeDef(
+    _RequiredPutThirdPartyJobSuccessResultInputRequestTypeDef,
+    _OptionalPutThirdPartyJobSuccessResultInputRequestTypeDef,
 ):
     pass
 
 
-_RequiredPutWebhookInputTypeDef = TypedDict(
-    "_RequiredPutWebhookInputTypeDef",
+_RequiredPutWebhookInputRequestTypeDef = TypedDict(
+    "_RequiredPutWebhookInputRequestTypeDef",
     {
         "webhook": "WebhookDefinitionTypeDef",
     },
 )
-_OptionalPutWebhookInputTypeDef = TypedDict(
-    "_OptionalPutWebhookInputTypeDef",
+_OptionalPutWebhookInputRequestTypeDef = TypedDict(
+    "_OptionalPutWebhookInputRequestTypeDef",
     {
         "tags": List["TagTypeDef"],
     },
@@ -1451,20 +1459,22 @@ _OptionalPutWebhookInputTypeDef = TypedDict(
 )
 
 
-class PutWebhookInputTypeDef(_RequiredPutWebhookInputTypeDef, _OptionalPutWebhookInputTypeDef):
+class PutWebhookInputRequestTypeDef(
+    _RequiredPutWebhookInputRequestTypeDef, _OptionalPutWebhookInputRequestTypeDef
+):
     pass
 
 
-PutWebhookOutputResponseTypeDef = TypedDict(
-    "PutWebhookOutputResponseTypeDef",
+PutWebhookOutputTypeDef = TypedDict(
+    "PutWebhookOutputTypeDef",
     {
         "webhook": "ListWebhookItemTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-RegisterWebhookWithThirdPartyInputTypeDef = TypedDict(
-    "RegisterWebhookWithThirdPartyInputTypeDef",
+RegisterWebhookWithThirdPartyInputRequestTypeDef = TypedDict(
+    "RegisterWebhookWithThirdPartyInputRequestTypeDef",
     {
         "webhookName": str,
     },
@@ -1482,8 +1492,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-RetryStageExecutionInputTypeDef = TypedDict(
-    "RetryStageExecutionInputTypeDef",
+RetryStageExecutionInputRequestTypeDef = TypedDict(
+    "RetryStageExecutionInputRequestTypeDef",
     {
         "pipelineName": str,
         "stageName": str,
@@ -1492,8 +1502,8 @@ RetryStageExecutionInputTypeDef = TypedDict(
     },
 )
 
-RetryStageExecutionOutputResponseTypeDef = TypedDict(
-    "RetryStageExecutionOutputResponseTypeDef",
+RetryStageExecutionOutputTypeDef = TypedDict(
+    "RetryStageExecutionOutputTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1586,14 +1596,14 @@ StageStateTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredStartPipelineExecutionInputTypeDef = TypedDict(
-    "_RequiredStartPipelineExecutionInputTypeDef",
+_RequiredStartPipelineExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredStartPipelineExecutionInputRequestTypeDef",
     {
         "name": str,
     },
 )
-_OptionalStartPipelineExecutionInputTypeDef = TypedDict(
-    "_OptionalStartPipelineExecutionInputTypeDef",
+_OptionalStartPipelineExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalStartPipelineExecutionInputRequestTypeDef",
     {
         "clientRequestToken": str,
     },
@@ -1601,14 +1611,15 @@ _OptionalStartPipelineExecutionInputTypeDef = TypedDict(
 )
 
 
-class StartPipelineExecutionInputTypeDef(
-    _RequiredStartPipelineExecutionInputTypeDef, _OptionalStartPipelineExecutionInputTypeDef
+class StartPipelineExecutionInputRequestTypeDef(
+    _RequiredStartPipelineExecutionInputRequestTypeDef,
+    _OptionalStartPipelineExecutionInputRequestTypeDef,
 ):
     pass
 
 
-StartPipelineExecutionOutputResponseTypeDef = TypedDict(
-    "StartPipelineExecutionOutputResponseTypeDef",
+StartPipelineExecutionOutputTypeDef = TypedDict(
+    "StartPipelineExecutionOutputTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1623,15 +1634,15 @@ StopExecutionTriggerTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredStopPipelineExecutionInputTypeDef = TypedDict(
-    "_RequiredStopPipelineExecutionInputTypeDef",
+_RequiredStopPipelineExecutionInputRequestTypeDef = TypedDict(
+    "_RequiredStopPipelineExecutionInputRequestTypeDef",
     {
         "pipelineName": str,
         "pipelineExecutionId": str,
     },
 )
-_OptionalStopPipelineExecutionInputTypeDef = TypedDict(
-    "_OptionalStopPipelineExecutionInputTypeDef",
+_OptionalStopPipelineExecutionInputRequestTypeDef = TypedDict(
+    "_OptionalStopPipelineExecutionInputRequestTypeDef",
     {
         "abandon": bool,
         "reason": str,
@@ -1640,22 +1651,23 @@ _OptionalStopPipelineExecutionInputTypeDef = TypedDict(
 )
 
 
-class StopPipelineExecutionInputTypeDef(
-    _RequiredStopPipelineExecutionInputTypeDef, _OptionalStopPipelineExecutionInputTypeDef
+class StopPipelineExecutionInputRequestTypeDef(
+    _RequiredStopPipelineExecutionInputRequestTypeDef,
+    _OptionalStopPipelineExecutionInputRequestTypeDef,
 ):
     pass
 
 
-StopPipelineExecutionOutputResponseTypeDef = TypedDict(
-    "StopPipelineExecutionOutputResponseTypeDef",
+StopPipelineExecutionOutputTypeDef = TypedDict(
+    "StopPipelineExecutionOutputTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-TagResourceInputTypeDef = TypedDict(
-    "TagResourceInputTypeDef",
+TagResourceInputRequestTypeDef = TypedDict(
+    "TagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
         "tags": List["TagTypeDef"],
@@ -1715,30 +1727,30 @@ TransitionStateTypeDef = TypedDict(
     total=False,
 )
 
-UntagResourceInputTypeDef = TypedDict(
-    "UntagResourceInputTypeDef",
+UntagResourceInputRequestTypeDef = TypedDict(
+    "UntagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
         "tagKeys": List[str],
     },
 )
 
-UpdateActionTypeInputTypeDef = TypedDict(
-    "UpdateActionTypeInputTypeDef",
+UpdateActionTypeInputRequestTypeDef = TypedDict(
+    "UpdateActionTypeInputRequestTypeDef",
     {
         "actionType": "ActionTypeDeclarationTypeDef",
     },
 )
 
-UpdatePipelineInputTypeDef = TypedDict(
-    "UpdatePipelineInputTypeDef",
+UpdatePipelineInputRequestTypeDef = TypedDict(
+    "UpdatePipelineInputRequestTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
     },
 )
 
-UpdatePipelineOutputResponseTypeDef = TypedDict(
-    "UpdatePipelineOutputResponseTypeDef",
+UpdatePipelineOutputTypeDef = TypedDict(
+    "UpdatePipelineOutputTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
